WellKnownTypes

Enum WellKnownTypes 

pub enum WellKnownTypes {
    Listener,
    HttpConnectionManager,
    RouteConfiguration,
    ScopedRouteConfiguration,
    VirtualHost,
    Cluster,
    ClusterLoadAssignment,
    Secret,
    Runtime,
}
Well known types that Any messages may contain while dealing with XDS DiscoveryRequests and DiscoveryResponses.

This type currently suppors the top-level types for xDS services and the HttpConnectionManager type that most applications will need to work with while managing a Listener. It doesn’t include support for extension types or typed configs.

match WellKnownTypes::from_type_url(&any.type_url) {
    Some(WellKnownTypes::Listener) => {
        do_something_with_listener(Listener::decode(&any.value).unwrap())
    }
    _ => todo!(),
}

pbjson

With the pbjson feature enabled, Any messages use WellKnownTypes for canonical json conversion and any type listed in WellKnownTypes will be serialized as a struct instead of as an opaque blob. For example, an Any containing an HttpConnectionManager would serialize to.

{
    "@type": "type.googleapis.com/envoy.extensions.filters.network.http_connection_manager.v3.HttpConnectionManager",
    "route_config": {
        "name": "test_route"
    }
}

Variants



Listener

An XDS Listener for LDS.



HttpConnectionManager

An HttpConnectionManager, included in XDS Listeners.



RouteConfiguration

A RouteConfiguration type, used in RDS.



ScopedRouteConfiguration

A ScopedRouteConfiguration, used in SRDS.



VirtualHost

A VirtualHost, used in VHDS.



Cluster

A Cluster, used in CDS



ClusterLoadAssignment

A ClusterLoadAssignment, used in EDS.



Secret

A Secret, used in SDS.



Runtime

A Runtime, used in RTDS.

Implementations

Source

impl WellKnownTypes

pub fn all() -> &'static [WellKnownTypes]

pub fn from_type_url(type_url: &str) -> Option<Self>

pub fn type_url(&self) -> &'static str