SubstitutionFormatString

Struct SubstitutionFormatString 

pub struct SubstitutionFormatString {
    pub omit_empty_values: bool,
    pub content_type: String,
    pub formatters: Vec<TypedExtensionConfig>,
    pub json_format_options: Option<JsonFormatOptions>,
    pub format: Option<Format>,
}
Configuration to use multiple :ref:command operators <config_access_log_command_operators> to generate a new string in either plain text or JSON format. [#next-free-field: 8]

Fields

omit_empty_values: bool

If set to true, when command operators are evaluated to null,

  • for text_format, the output of the empty operator is changed from - to an empty string, so that empty values are omitted entirely.
  • for json_format the keys with null values are omitted in the output structure.
content_type: String

Specify a content_type field. If this field is not set then text/plain is used for text_format and application/json is used for json_format.

.. validated-code-block:: yaml :type-name: envoy.config.core.v3.SubstitutionFormatString

content_type: “text/html; charset=UTF-8”

formatters: Vec<TypedExtensionConfig>

Specifies a collection of Formatter plugins that can be called from the access log configuration. See the formatters extensions documentation for details. [#extension-category: envoy.formatter]

json_format_options: Option<JsonFormatOptions>

If json_format is used, the options will be applied to the output JSON string.

format: Option<Format>