pub struct ResponseFlags {Show 28 fields
pub failed_local_healthcheck: bool,
pub no_healthy_upstream: bool,
pub upstream_request_timeout: bool,
pub local_reset: bool,
pub upstream_remote_reset: bool,
pub upstream_connection_failure: bool,
pub upstream_connection_termination: bool,
pub upstream_overflow: bool,
pub no_route_found: bool,
pub delay_injected: bool,
pub fault_injected: bool,
pub rate_limited: bool,
pub unauthorized_details: Option<Unauthorized>,
pub rate_limit_service_error: bool,
pub downstream_connection_termination: bool,
pub upstream_retry_limit_exceeded: bool,
pub stream_idle_timeout: bool,
pub invalid_envoy_request_headers: bool,
pub downstream_protocol_error: bool,
pub upstream_max_stream_duration_reached: bool,
pub response_from_cache_filter: bool,
pub no_filter_config_found: bool,
pub duration_timeout: bool,
pub upstream_protocol_error: bool,
pub no_cluster_found: bool,
pub overload_manager: bool,
pub dns_resolution_failure: bool,
pub downstream_remote_reset: bool,
}Expand description
Flags indicating occurrences during request/response processing. [#next-free-field: 29]
Fields
failed_local_healthcheck: boolIndicates local server healthcheck failed.
no_healthy_upstream: boolIndicates there was no healthy upstream.
upstream_request_timeout: boolIndicates an there was an upstream request timeout.
local_reset: boolIndicates local codec level reset was sent on the stream.
upstream_remote_reset: boolIndicates remote codec level reset was received on the stream.
upstream_connection_failure: boolIndicates there was a local reset by a connection pool due to an initial connection failure.
upstream_connection_termination: boolIndicates the stream was reset due to an upstream connection termination.
upstream_overflow: boolIndicates the stream was reset because of a resource overflow.
no_route_found: boolIndicates no route was found for the request.
delay_injected: boolIndicates that the request was delayed before proxying.
fault_injected: boolIndicates that the request was aborted with an injected error code.
rate_limited: boolIndicates that the request was rate-limited locally.
Indicates if the request was deemed unauthorized and the reason for it.
rate_limit_service_error: boolIndicates that the request was rejected because there was an error in rate limit service.
downstream_connection_termination: boolIndicates the stream was reset due to a downstream connection termination.
upstream_retry_limit_exceeded: boolIndicates that the upstream retry limit was exceeded, resulting in a downstream error.
stream_idle_timeout: boolIndicates that the stream idle timeout was hit, resulting in a downstream 408.
invalid_envoy_request_headers: boolIndicates that the request was rejected because an envoy request header failed strict validation.
downstream_protocol_error: boolIndicates there was an HTTP protocol error on the downstream request.
upstream_max_stream_duration_reached: boolIndicates there was a max stream duration reached on the upstream request.
response_from_cache_filter: boolIndicates the response was served from a cache filter.
no_filter_config_found: boolIndicates that a filter configuration is not available.
duration_timeout: boolIndicates that request or connection exceeded the downstream connection duration.
upstream_protocol_error: boolIndicates there was an HTTP protocol error in the upstream response.
no_cluster_found: boolIndicates no cluster was found for the request.
overload_manager: boolIndicates overload manager terminated the request.
dns_resolution_failure: boolIndicates a DNS resolution failed.
downstream_remote_reset: boolIndicates a downstream remote codec level reset was received on the stream