pub struct SocketBufferedTrace {
pub trace_id: u64,
pub connection: Option<Connection>,
pub events: Vec<SocketEvent>,
pub read_truncated: bool,
pub write_truncated: bool,
}Expand description
Sequence of read/write events that constitute a buffered trace on a socket. [#next-free-field: 6]
Fields
trace_id: u64Trace ID unique to the originating Envoy only. Trace IDs can repeat and should not be used for long term stable uniqueness. Matches connection IDs used in Envoy logs.
connection: Option<Connection>Connection properties.
events: Vec<SocketEvent>Sequence of observed events.
read_truncated: boolSet to true if read events were truncated due to the :ref:max_buffered_rx_bytes <envoy_v3_api_field_config.tap.v3.OutputConfig.max_buffered_rx_bytes> setting.
write_truncated: boolSet to true if write events were truncated due to the :ref:max_buffered_tx_bytes <envoy_v3_api_field_config.tap.v3.OutputConfig.max_buffered_tx_bytes> setting.