pub struct SubstitutionFormatString {
pub omit_empty_values: bool,
pub content_type: String,
pub formatters: Vec<TypedExtensionConfig>,
pub json_format_options: Option<JsonFormatOptions>,
pub format: Option<Format>,
}Expand description
Configuration to use multiple :ref:command operators <config_access_log_command_operators>
to generate a new string in either plain text or JSON format.
[#next-free-field: 8]
Fields
omit_empty_values: boolIf set to true, when command operators are evaluated to null,
- for
text_format, the output of the empty operator is changed from-to an empty string, so that empty values are omitted entirely. - for
json_formatthe keys with null values are omitted in the output structure.
content_type: StringSpecify a content_type field.
If this field is not set then text/plain is used for text_format and
application/json is used for json_format.
.. validated-code-block:: yaml :type-name: envoy.config.core.v3.SubstitutionFormatString
content_type: “text/html; charset=UTF-8”
formatters: Vec<TypedExtensionConfig>Specifies a collection of Formatter plugins that can be called from the access log configuration. See the formatters extensions documentation for details. [#extension-category: envoy.formatter]
json_format_options: Option<JsonFormatOptions>If json_format is used, the options will be applied to the output JSON string.
format: Option<Format>Trait Implementations
Sourceimpl Clone for SubstitutionFormatString
impl Clone for SubstitutionFormatString
Sourcefn clone(&self) -> SubstitutionFormatString
fn clone(&self) -> SubstitutionFormatString
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SubstitutionFormatString
impl Debug for SubstitutionFormatString
Sourceimpl Default for SubstitutionFormatString
impl Default for SubstitutionFormatString
Sourceimpl Message for SubstitutionFormatString
impl Message for SubstitutionFormatString
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self.Sourceimpl Name for SubstitutionFormatString
impl Name for SubstitutionFormatString
Sourceconst NAME: &'static str = "SubstitutionFormatString"
const NAME: &'static str = "SubstitutionFormatString"
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "envoy.config.core.v3"
const PACKAGE: &'static str = "envoy.config.core.v3"
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for SubstitutionFormatString
impl PartialEq for SubstitutionFormatString
Sourcefn eq(&self, other: &SubstitutionFormatString) -> bool
fn eq(&self, other: &SubstitutionFormatString) -> bool
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SubstitutionFormatString